## dbt-bigquery 1.10.0-rc1 - June 04, 2025

### Breaking Changes

- rename 'catalog' model config value to 'catalog_name' ([#1134](https://github.com/dbt-labs/dbt-adapters/issues/1134))

### Features

- Make Bigquery `api_endpoint` config option available for dbt client ([#https://github.com/dbt-labs/dbt-bigquery/pull/1017](https://github.com/dbt-labs/dbt-adapters/issues/https://github.com/dbt-labs/dbt-bigquery/pull/1017))
- Add support for managed Iceberg catalogs ([#1105](https://github.com/dbt-labs/dbt-adapters/issues/1105))
- generate storage_uri from external_volume, base_location_root and base_location_subpath ([#1129](https://github.com/dbt-labs/dbt-adapters/issues/1129))

### Fixes

- Set partial ordering mode as default in dbt bigframes ([#1035](https://github.com/dbt-labs/dbt-adapters/issues/1035))
- Set 1 hour as default timeout in bigframes mode ([#1070](https://github.com/dbt-labs/dbt-adapters/issues/1070))
- Set job_retry to None to resolve Google Cloud warning ([##1088](https://github.com/dbt-labs/dbt-adapters/issues/#1088))

### Under the Hood

- populate file_format from top level integration config field ([#1129](https://github.com/dbt-labs/dbt-adapters/issues/1129))
- Rename and separate out info schema and biglake catalog integrations ([#1129](https://github.com/dbt-labs/dbt-adapters/issues/1129))

### Dependencies

- bump dbt-core requirement to 1.10.0rc0 ([#1142](https://github.com/dbt-labs/dbt-adapters/pull/1142))

### Contributors
- [@OTooleMichael](https://github.com/OTooleMichael) ([#https://github.com/dbt-labs/dbt-bigquery/pull/1017](https://github.com/dbt-labs/dbt-adapters/issues/https://github.com/dbt-labs/dbt-bigquery/pull/1017))
- [@jialuoo](https://github.com/jialuoo) ([#1035](https://github.com/dbt-labs/dbt-adapters/issues/1035), [#1070](https://github.com/dbt-labs/dbt-adapters/issues/1070))
- [@katieclaiborne-duet](https://github.com/katieclaiborne-duet) ([##1088](https://github.com/dbt-labs/dbt-adapters/issues/#1088))
